@@ -60,32 +60,51 @@ KSysGuardDaemon::KSysGuardDaemon()
     timer->start();
 }
 
+KSysGuardDaemon::~KSysGuardDaemon()
+{
+    for (Client* c : m_clients) {
+        delete c;
+    }
+}
+
 void KSysGuardDaemon::init()
 {
     loadProviders();
     QDBusConnection::sessionBus().registerObject("/", this, QDBusConnection::ExportAdaptors);
-    QDBusConnection::sessionBus().registerService("org.kde.ksystemstats");
+    if (!QDBusConnection::sessionBus().registerService("org.kde.ksystemstats")) {
+        qCritical() << "Unable to register DBus service org.kde.ksystemstats. Maybe it is already running?";
+        exit(1);
+    }
 }
 
 void KSysGuardDaemon::loadProviders()
 {
     //instantiate all plugins
-
-    QPluginLoader loader;
-    KPluginLoader::forEachPlugin(QStringLiteral("ksysguard"), [&loader, this](const QString &pluginPath) {
-        loader.setFileName(pluginPath);
-        QObject* obj = loader.instance();
-        auto factory = qobject_cast<KPluginFactory*>(obj);
-        if (!factory) {
-            qWarning() << "Failed to load ksysguard factory";
-            return;
+    const auto plugins = KPluginLoader::instantiatePlugins(QStringLiteral("ksysguard"), [this](const KPluginMetaData &metaData) {
+        auto providerName = metaData.rawData().value("providerName").toString();
+        auto itr = std::find_if(m_providers.cbegin(), m_providers.cend(), [providerName](SensorPlugin *plugin) {
+            return plugin->providerName() == providerName;
+        });
+        if (itr != m_providers.cend()) {
+            return false;
         }
-        SensorPlugin *provider = factory->create<SensorPlugin>(this);
+
+        return true;
+    }, this);
+
+    for (auto object : plugins) {
+        auto factory = qobject_cast<KPluginFactory*>(object);
+        if (!factory) {
+            qWarning() << "Plugin object" << object << "did not provide a proper KPluginFactory";
+            continue;
+        }
+        auto provider = factory->create<SensorPlugin>(this);
         if (!provider) {
-            return;
+            qWarning() << "Plugin object" << object << "did not provide a proper SensorPlugin";
+            continue;
         }
         registerProvider(provider);
-    });
+    }
 
     if (m_providers.isEmpty()) {
         qWarning() << "No plugins found";
@@ -93,14 +112,6 @@ void KSysGuardDaemon::loadProviders()
 }
 
 void KSysGuardDaemon::registerProvider(SensorPlugin *provider) {
-    auto itr = std::find_if(m_providers.cbegin(), m_providers.cend(), [provider](SensorPlugin *plugin) {
-        return plugin->providerName() == provider->providerName();
-    });
-    if (itr != m_providers.cend()) {
-        return;
-    }
-
-
     m_providers.append(provider);
     const auto containers = provider->containers();
     for (auto container : containers) {
