@@ -22,7 +22,7 @@
 #include "AggregateSensor.h"
 
 #include <KLocalizedString>
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 #include <ksgrd/SensorManager.h>
 
 #include <QEventLoop>
@@ -43,7 +43,6 @@ KSGRDIface::KSGRDIface(QObject *parent, const QVariantList &args)
     registerSubsystem("disk");
     registerSubsystem("lmsensors");
     registerSubsystem("mem");
-    registerSubsystem("network");
     registerSubsystem("partitions");
     registerSubsystem("uptime");
     registerSubsystem("system");
@@ -131,8 +130,7 @@ void KSGRDIface::onSensorMetaDataRetrieved(int id, const QList<QByteArray> &answ
     const QString propertyId = key.mid(propertyIndex + 1);
 
     auto subsystem = m_subsystems[subsystemId];
-    if (Q_UNLIKELY(!subsystem)) {
-        qDebug() << "could not find subsystem" << subsystemId;
+    if (!subsystem) {
         return;
     }
     auto sensorObject = subsystem->object(objectId);
@@ -253,21 +251,21 @@ void KSGRDIface::onSensorUpdated(int id, const QList<QByteArray> &answer)
     }
 }
 
-KSysGuard::utils::Unit KSGRDIface::unitFromString(const QString &unitString) const
+KSysGuard::Unit KSGRDIface::unitFromString(const QString &unitString) const
 {
     using namespace KSysGuard;
-    static const QHash<QString, utils::Unit> map({ { "%", utils::UnitPercent },
-        { "1/s", utils::UnitRate },
-        { "°C", utils::UnitCelsius },
-        { "dBm", utils::UnitDecibelMilliWatts },
-        { "KB", utils::UnitKiloByte },
-        { "KB/s", utils::UnitKiloByteRate },
-        { "MHz", utils::UnitMegaHertz },
-        { "port", utils::UnitNone },
-        { "rpm", utils::UnitRpm },
-        { "s", utils::UnitTime },
-        { "V", utils::UnitVolt } });
-    return map.value(unitString, utils::UnitNone);
+    static const QHash<QString, Unit> map({ { "%", UnitPercent },
+        { "1/s", UnitRate },
+        { "°C", UnitCelsius },
+        { "dBm", UnitDecibelMilliWatts },
+        { "KB", UnitKiloByte },
+        { "KB/s", UnitKiloByteRate },
+        { "MHz", UnitMegaHertz },
+        { "port", UnitNone },
+        { "rpm", UnitRpm },
+        { "s", UnitTime },
+        { "V", UnitVolt } });
+    return map.value(unitString, UnitNone);
 }
 
 void KSGRDIface::update()
@@ -307,47 +305,19 @@ void KSGRDIface::answerReceived(int id, const QList<QByteArray> &answer)
 
 void KSGRDIface::addAggregateSensors()
 {
-    auto networkAll = new SensorObject("all", i18nc("@title All Network Interfaces", "All"), m_subsystems["network"]);
-
-    auto sensor = new AggregateSensor(networkAll, "receivedDataRate", i18nc("@title", "Received Data Rate"));
-    sensor->setShortName(i18nc("@title Received Data Rate", "Down"));
-    sensor->setMatchSensors(QRegularExpression("[^/]*/receiver"), QStringLiteral("data"));
-    sensor->setDescription(i18nc("@info", "The rate at which data is received on all interfaces."));
-    sensor->setUnit(KSysGuard::utils::UnitKiloByteRate);
-
-    sensor = new AggregateSensor(networkAll, "totalReceivedData", i18nc("@title", "Total Received Data"));
-    sensor->setShortName(i18nc("@title Total Receieved Data", "Total Down"));
-    sensor->setMatchSensors(QRegularExpression("[^/]*/receiver"), QStringLiteral("dataTotal"));
-    sensor->setDescription(i18nc("@info", "The total amount of data received on all interfaces."));
-    sensor->setUnit(KSysGuard::utils::UnitKiloByte);
-
-    sensor = new AggregateSensor(networkAll, "sentDataRate", i18nc("@title", "Sent Data Rate"));
-    sensor->setShortName(i18nc("@title Sent Data Rate", "Up"));
-    sensor->setMatchSensors(QRegularExpression("[^/]*/transmitter"), QStringLiteral("data"));
-    sensor->setDescription(i18nc("@info", "The rate at which data is sent on all interfaces."));
-    sensor->setUnit(KSysGuard::utils::UnitKiloByteRate);
-
-    sensor = new AggregateSensor(networkAll, "totalSentData", i18nc("@title", "Total Sent Data"));
-    sensor->setShortName(i18nc("@title Total Sent Data", "Total Up"));
-    sensor->setMatchSensors(QRegularExpression("[^/]*/transmitter"), QStringLiteral("dataTotal"));
-    sensor->setDescription(i18nc("@info", "The total amount of data sent on all interfaces."));
-    sensor->setUnit(KSysGuard::utils::UnitKiloByte);
-
     auto diskAll = new SensorObject("all", i18nc("@title All Disks", "All"), m_subsystems["disk"]);
-    sensor = new AggregateSensor(diskAll, "read", i18nc("@title", "Disk Read Accesses"));
+    auto sensor = new AggregateSensor(diskAll, "read", i18nc("@title", "Disk Read Accesses"));
     sensor->setShortName(i18nc("@title Disk Read Accesses", "Read"));
     // TODO: This regex is not exhaustive as it doesn't consider things that aren't treated as sdX devices.
     //       However, we do not simply want to match disk/* as that would include duplicate devices.
     sensor->setMatchSensors(QRegularExpression("^sd[a-z]+[0-9]+_[^/]*/Rate$"), QStringLiteral("rblk"));
     sensor->setDescription(i18nc("@info", "Read accesses across all disk devices"));
-    sensor->setUnit(KSysGuard::utils::UnitKiloByteRate);
 
     sensor = new AggregateSensor(diskAll, "write", i18nc("@title", "Disk Write Accesses"));
     sensor->setShortName(i18nc("@title Disk Write Accesses", "Write"));
     // TODO: See above.
     sensor->setMatchSensors(QRegularExpression("^sd[a-z]+[0-9]+_[^/]*/Rate$"), QStringLiteral("wblk"));
     sensor->setDescription(i18nc("@info", "Write accesses across all disk devices"));
-    sensor->setUnit(KSysGuard::utils::UnitKiloByteRate);
 
     auto memPhysical = m_subsystems["mem"]->object("physical");
     Q_ASSERT(memPhysical);
@@ -401,7 +371,7 @@ QString KSGRDIface::shortNameFor(const QString &key)
         { QStringLiteral("mem/physical/used"), i18nc("@title Total Memory Usage", "Total Used") },
         { QStringLiteral("mem/physical/cached"), i18nc("@title Cached Memory Usage", "Cached") },
         { QStringLiteral("mem/physical/free"), i18nc("@title Free Memory Amount", "Free") },
-        { QStringLiteral("mem/physical/available"), i18nc("@title Available Memory Amount", "Avalable") },
+        { QStringLiteral("mem/physical/available"), i18nc("@title Available Memory Amount", "Available") },
         { QStringLiteral("mem/physical/application"), i18nc("@title Application Memory Usage", "Application") },
         { QStringLiteral("mem/physical/buf"), i18nc("@title Buffer Memory Usage", "Buffer") },
         { QStringLiteral("cpu/system/processors"), i18nc("@title Number of Processors", "Processors") },
@@ -411,6 +381,6 @@ QString KSGRDIface::shortNameFor(const QString &key)
     return shortNames.value(key, QString {});
 }
 
-K_PLUGIN_FACTORY(KSGRDPluginFactory, registerPlugin<KSGRDIface>();)
+K_PLUGIN_CLASS_WITH_JSON(KSGRDIface, "metadata.json")
 
 #include "ksgrdiface.moc"
